@@ -1,21 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
 /*
- * This file is part of Devhelp.
- *
- * Copyright (C) 2012 Aleksander Morgado <aleksander@gnu.org>
- *
- * Devhelp is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published
- * by the Free Software Foundation, either version 3 of the License,
- * or (at your option) any later version.
- *
- * Devhelp is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with Devhelp.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-FileCopyrightText: 2012 Aleksander Morgado <aleksander@gnu.org>
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #ifndef DEVHELP_H
@@ -25,6 +11,7 @@
 
 #include <devhelp/dh-enum-types.h>
 
+#include <devhelp/dh-application-window.h>
 #include <devhelp/dh-assistant-view.h>
 #include <devhelp/dh-book.h>
 #include <devhelp/dh-book-list.h>
@@ -46,6 +33,5 @@
 #include <devhelp/dh-tab.h>
 #include <devhelp/dh-tab-label.h>
 #include <devhelp/dh-web-view.h>
-#include <devhelp/dh-window.h>
 
 #endif /* DEVHELP_H */
